KeriDartPlatform class

Constructors

KeriDartPlatform(DynamicLibrary dylib)

Properties

dropPort → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inner → KeriDartWire
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

api2wire_box_autoadd_config(Config raw) → Pointer<wire_Config>
api2wire_box_autoadd_digest_type(DigestType raw) → Pointer<wire_DigestType>
api2wire_box_autoadd_identifier(Identifier raw) → Pointer<wire_Identifier>
api2wire_box_autoadd_signature(Signature raw) → Pointer<wire_Signature>
api2wire_box_signature(Signature raw) → Pointer<wire_Signature>
api2wire_list_data_and_signature(List<DataAndSignature> raw) → Pointer<wire_list_data_and_signature>
api2wire_list_identifier(List<Identifier> raw) → Pointer<wire_list_identifier>
api2wire_list_public_key(List<PublicKey> raw) → Pointer<wire_list_public_key>
api2wire_opt_box_autoadd_config(Config? raw) → Pointer<wire_Config>
api2wire_String(String raw) → Pointer<wire_uint_8_list>
api2wire_StringList(List<String> raw) → Pointer<wire_StringList>
api2wire_u64(int raw) → int
api2wire_uint_8_list(Uint8List raw) → Pointer<wire_uint_8_list>
dispose() → void
inherited
executeNormal<S, E extends Object>(FlutterRustBridgeTask<S, E> task) → Future<S>
Execute a normal ffi call. Usually called by generated code instead of manually called.
inherited
executeStream<S, E extends Object>(FlutterRustBridgeTask<S, E> task) → Stream<S>
Similar to executeNormal, except that this will return a Stream instead of a Future.
inherited
executeSync<S>(FlutterRustBridgeSyncTask task) → S
Similar to executeNormal, except that this will return synchronously
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited